@@ -1,4 +1,4 @@
-﻿define(['jQuery'], function ($) {
+﻿define([], function () {
 
     function login(page, username, password) {
 
@@ -18,7 +18,7 @@
                 title: Globalize.translate('HeaderLoginFailure')
             });
 
-            $('#txtManualPassword', page).val('');
+            page.querySelector('#txtManualPassword').value = '';
 
         });
 
@@ -102,28 +102,29 @@
     function loadMode(page, mode) {
 
         if (mode == 'welcome') {
-            $('.connectLoginForm', page).hide();
-            $('.welcomeContainer', page).show();
-            $('.manualServerForm', page).hide();
-            $('.signupForm', page).hide();
+
+            page.querySelector('.connectLoginForm').classList.add('hide');
+            page.querySelector('.welcomeContainer').classList.remove('hide');
+            page.querySelector('.manualServerForm').classList.add('hide');
+            page.querySelector('.signupForm').classList.add('hide');
         }
         else if (mode == 'connect') {
-            $('.connectLoginForm', page).show();
-            $('.welcomeContainer', page).hide();
-            $('.manualServerForm', page).hide();
-            $('.signupForm', page).hide();
+            page.querySelector('.connectLoginForm').classList.remove('hide');
+            page.querySelector('.welcomeContainer').classList.add('hide');
+            page.querySelector('.manualServerForm').classList.add('hide');
+            page.querySelector('.signupForm').classList.add('hide');
         }
         else if (mode == 'manualserver') {
-            $('.manualServerForm', page).show();
-            $('.connectLoginForm', page).hide();
-            $('.welcomeContainer', page).hide();
-            $('.signupForm', page).hide();
+            page.querySelector('.manualServerForm').classList.remove('hide');
+            page.querySelector('.connectLoginForm').classList.add('hide');
+            page.querySelector('.welcomeContainer').classList.add('hide');
+            page.querySelector('.signupForm').classList.add('hide');
         }
         else if (mode == 'signup') {
-            $('.manualServerForm', page).hide();
-            $('.connectLoginForm', page).hide();
-            $('.welcomeContainer', page).hide();
-            $('.signupForm', page).show();
+            page.querySelector('.manualServerForm').classList.add('hide');
+            page.querySelector('.connectLoginForm').classList.add('hide');
+            page.querySelector('.welcomeContainer').classList.add('hide');
+            page.querySelector('.signupForm').classList.remove('hide');
             initSignup(page);
         }
     }
@@ -133,66 +134,6 @@
         Dashboard.navigate('selectserver.html');
     }
 
-    function onSubmit() {
-        var page = $(this).parents('.page');
-
-        submit(page);
-
-        return false;
-    }
-
-    function onManualServerSubmit() {
-        var page = $(this).parents('.page');
-
-        submitManualServer(page);
-
-        return false;
-    }
-
-    function onSignupFormSubmit() {
-
-        if (!supportInAppSignup()) {
-            return false;
-        }
-
-        var page = $(this).parents('.page');
-
-        ConnectionManager.signupForConnect($('#txtSignupEmail', page).val(), $('#txtSignupUsername', page).val(), $('#txtSignupPassword', page).val(), $('#txtSignupPasswordConfirm', page).val()).then(function () {
-
-            Dashboard.alert({
-                message: Globalize.translate('MessageThankYouForConnectSignUp'),
-                callback: function () {
-                    Dashboard.navigate('connectlogin.html?mode=welcome');
-                }
-            });
-
-        }, function (result) {
-
-            if (result.errorCode == 'passwordmatch') {
-                Dashboard.alert({
-                    message: Globalize.translate('ErrorMessagePasswordNotMatchConfirm')
-                });
-            }
-            else if (result.errorCode == 'USERNAME_IN_USE') {
-                Dashboard.alert({
-                    message: Globalize.translate('ErrorMessageUsernameInUse')
-                });
-            }
-            else if (result.errorCode == 'EMAIL_IN_USE') {
-                Dashboard.alert({
-                    message: Globalize.translate('ErrorMessageEmailInUse')
-                });
-            } else {
-                Dashboard.alert({
-                    message: Globalize.translate('DefaultErrorMessage')
-                });
-            }
-
-        });
-
-        return false;
-    }
-
     function requireCaptcha() {
         return !AppInfo.isNativeApp && window.location.href.toLowerCase().indexOf('https') == 0;
     }
@@ -217,78 +158,10 @@
         });
     }
 
-    $(document).on('pageinit', "#connectLoginPage", function () {
-
-        var page = this;
-
-        $('.btnSkipConnect', page).on('click', function () {
-            skip();
-        });
-
-        $('.connectLoginForm').off('submit', onSubmit).on('submit', onSubmit);
-        $('.manualServerForm').off('submit', onManualServerSubmit).on('submit', onManualServerSubmit);
-        $('.signupForm').off('submit', onSignupFormSubmit).on('submit', onSignupFormSubmit);
-
-        $('.btnSignupForConnect', page).on('click', function () {
-
-            if (supportInAppSignup()) {
-                Dashboard.navigate('connectlogin.html?mode=signup');
-                return false;
-            }
-        });
-
-        $('.btnCancelSignup', page).on('click', function () {
-
-            history.back();
-        });
-
-        $('.btnCancelManualServer', page).on('click', function () {
-
-            history.back();
-        });
-
-        $('.btnWelcomeNext', page).on('click', function () {
-            Dashboard.navigate('connectlogin.html?mode=connect');
-        });
-
-        var terms = page.querySelector('.terms');
-        terms.innerHTML = Globalize.translate('LoginDisclaimer') + "<div style='margin-top:5px;'><a href='http://emby.media/terms' target='_blank'>" + Globalize.translate('TermsOfUse') + "</a></div>";
-
-        if (AppInfo.isNativeApp) {
-            terms.classList.add('hide');
-            page.querySelector('.tvAppInfo').classList.add('hide');
-        } else {
-            terms.classList.remove('hide');
-            page.querySelector('.tvAppInfo').classList.remove('hide');
-        }
-
-    }).on('pagebeforeshow', "#connectLoginPage", function () {
-
-        var page = this;
-
-        $('#txtSignupEmail', page).val('');
-        $('#txtSignupUsername', page).val('');
-        $('#txtSignupPassword', page).val('');
-        $('#txtSignupPasswordConfirm', page).val('');
-
-        if (browserInfo.safari && AppInfo.isNativeApp) {
-            // With apple we can't even have a link to the site
-            $('.embyIntroDownloadMessage', page).html(Globalize.translate('EmbyIntroDownloadMessageWithoutLink'));
-        } else {
-            var link = '<a href="http://emby.media" target="_blank">http://emby.media</a>';
-            $('.embyIntroDownloadMessage', page).html(Globalize.translate('EmbyIntroDownloadMessage', link));
-        }
-
-    }).on('pageshow', "#connectLoginPage", function () {
-
-        var page = this;
-        loadPage(page);
-    });
-
     function submitManualServer(page) {
 
-        var host = $('#txtServerHost', page).val();
-        var port = $('#txtServerPort', page).val();
+        var host = page.querySelector('#txtServerHost').value;
+        var port = page.querySelector('#txtServerPort').value;
 
         if (port) {
             host += ':' + port;
@@ -310,10 +183,132 @@
 
     function submit(page) {
 
-        var user = $('#txtManualName', page).val();
-        var password = $('#txtManualPassword', page).val();
+        var user = page.querySelector('#txtManualName').value;
+        var password = page.querySelector('#txtManualPassword').value;
 
         login(page, user, password);
     }
 
+    return function (view, params) {
+
+        function onSubmit(e) {
+            submit(view);
+
+            e.preventDefault();
+            return false;
+        }
+
+        function onManualServerSubmit(e) {
+            submitManualServer(view);
+
+            e.preventDefault();
+            return false;
+        }
+
+        function onSignupFormSubmit(e) {
+
+            if (!supportInAppSignup()) {
+                e.preventDefault();
+                return false;
+            }
+
+            var page = view;
+
+            ConnectionManager.signupForConnect(page.querySelector('#txtSignupEmail', page).value, page.querySelector('#txtSignupUsername', page).value, page.querySelector('#txtSignupPassword', page).value, page.querySelector('#txtSignupPasswordConfirm', page).value).then(function () {
+
+                Dashboard.alert({
+                    message: Globalize.translate('MessageThankYouForConnectSignUp'),
+                    callback: function () {
+                        Dashboard.navigate('connectlogin.html?mode=welcome');
+                    }
+                });
+
+            }, function (result) {
+
+                if (result.errorCode == 'passwordmatch') {
+                    Dashboard.alert({
+                        message: Globalize.translate('ErrorMessagePasswordNotMatchConfirm')
+                    });
+                }
+                else if (result.errorCode == 'USERNAME_IN_USE') {
+                    Dashboard.alert({
+                        message: Globalize.translate('ErrorMessageUsernameInUse')
+                    });
+                }
+                else if (result.errorCode == 'EMAIL_IN_USE') {
+                    Dashboard.alert({
+                        message: Globalize.translate('ErrorMessageEmailInUse')
+                    });
+                } else {
+                    Dashboard.alert({
+                        message: Globalize.translate('DefaultErrorMessage')
+                    });
+                }
+
+            });
+
+            e.preventDefault();
+            return false;
+        }
+
+        view.querySelector('.btnSkipConnect').addEventListener('click', skip);
+
+        view.querySelector('.connectLoginForm').addEventListener('submit', onSubmit);
+        view.querySelector('.manualServerForm').addEventListener('submit', onManualServerSubmit);
+        view.querySelector('.signupForm').addEventListener('submit', onSignupFormSubmit);
+
+        view.querySelector('.btnSignupForConnect').addEventListener('click', function (e) {
+            if (supportInAppSignup()) {
+                e.preventDefault();
+                e.stopPropagation();
+                Dashboard.navigate('connectlogin.html?mode=signup');
+                return false;
+            }
+        });
+
+        view.querySelector('.btnCancelSignup').addEventListener('click', function () {
+            history.back();
+        });
+
+        view.querySelector('.btnCancelManualServer').addEventListener('click', function () {
+            history.back();
+        });
+
+        view.querySelector('.btnWelcomeNext').addEventListener('click', function () {
+            Dashboard.navigate('connectlogin.html?mode=connect');
+        });
+
+        var terms = view.querySelector('.terms');
+        terms.innerHTML = Globalize.translate('LoginDisclaimer') + "<div style='margin-top:5px;'><a href='http://emby.media/terms' target='_blank'>" + Globalize.translate('TermsOfUse') + "</a></div>";
+
+        if (AppInfo.isNativeApp) {
+            terms.classList.add('hide');
+            view.querySelector('.tvAppInfo').classList.add('hide');
+        } else {
+            terms.classList.remove('hide');
+            view.querySelector('.tvAppInfo').classList.remove('hide');
+        }
+
+        view.addEventListener('viewbeforeshow', function () {
+
+            var page = this;
+
+            page.querySelector('#txtSignupEmail').value = '';
+            page.querySelector('#txtSignupUsername').value = '';
+            page.querySelector('#txtSignupPassword').value = '';
+            page.querySelector('#txtSignupPasswordConfirm').value = '';
+
+            if (browserInfo.safari && AppInfo.isNativeApp) {
+                // With apple we can't even have a link to the site
+                page.querySelector('.embyIntroDownloadMessage').innerHTML = Globalize.translate('EmbyIntroDownloadMessageWithoutLink');
+            } else {
+                var link = '<a href="http://emby.media" target="_blank">http://emby.media</a>';
+                page.querySelector('.embyIntroDownloadMessage').innerHTML = Globalize.translate('EmbyIntroDownloadMessage', link);
+            }
+        });
+
+        view.addEventListener('viewshow', function () {
+            loadPage(view);
+        });
+    };
 });
\ No newline at end of file
