@@ -1,4 +1,9 @@
-﻿define(['jQuery'], function ($) {
+﻿define(['events'], function (events) {
+
+    function onListingsSubmitted() {
+
+        Dashboard.navigate('livetvstatus.html');
+    }
 
     function init(page, type, providerId) {
 
@@ -9,6 +14,8 @@
             var instance = new factory(page, providerId, {
             });
 
+            events.on(instance, 'submitted', onListingsSubmitted);
+
             instance.init();
         });
     }
@@ -30,7 +37,7 @@
         xhr.send();
     }
 
-    $(document).on('pageshow', "#liveTvGuideProviderPage", function () {
+    pageIdOn('pageshow', "liveTvGuideProviderPage", function () {
 
         Dashboard.showLoadingMsg();
 
