@@ -76,7 +76,7 @@
             elem.innerHTML = html;
 
             var listItems = [];
-            var elems = elem.querySelectorAll('PAPER-ICON-ITEM');
+            var elems = elem.querySelectorAll('.listItem');
             for (var i = 0, length = elems.length; i < length; i++) {
                 listItems.push(elems[i]);
             }
@@ -100,16 +100,7 @@
             }
 
             ImageLoader.lazyChildren(elem);
-            $(elem).createCardMenus();
-
-            $(elem).off('needsrefresh').on('needsrefresh', function () {
-
-                reloadItems(page, item);
-
-            }).off('removefromplaylist').on('removefromplaylist', function (e, playlistItemId) {
-
-                removeFromPlaylist(page, item, [playlistItemId]);
-            });
+            LibraryBrowser.createCardMenus(elem);
 
             $('.btnNextPage', elem).on('click', function () {
                 query.StartIndex += query.Limit;
@@ -189,9 +180,30 @@
         });
     }
 
+    function init(page, item) {
+
+        var elem = page.querySelector('#childrenContent .itemsContainer');
+
+        elem.addEventListener('removefromplaylist', function (e) {
+
+            var playlistItemId = e.detail.playlistItemId;
+            removeFromPlaylist(page, item, [playlistItemId]);
+        });
+
+        elem.addEventListener('needsrefresh', function () {
+
+            reloadItems(page, item);
+        });
+    }
+
     window.PlaylistViewer = {
         render: function (page, item) {
 
+            if (!page.playlistInit) {
+                page.playlistInit = true;
+                init(page, item);
+            }
+
             reloadItems(page, item);
             showDragAndDropHelp();
         }
